# CRIPT (A Community Resource for Innovation in Polymer Technology)

CRIPT is an ecosystem of data standards, web-based applications, and software
frameworks for polymers. More information here: http://cript.mit.edu.

`cript` is the Python SDK for the CRIPT ecosystem.
